==> plasma-framework-5.94.0.zip: plasma-framework-5.94.0/src/desktoptheme/breeze/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[it]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队"
            }
        ],
        "Category": "",
        "Description": "Breeze by the KDE VDG",
        "Description[az]": "KDE VDG tərəfindən Breeze İş mühiti görünüşü",
        "Description[ca@valencia]": "Brisa, creat pel VDG de KDE",
        "Description[ca]": "Brisa, creat pel VDG del KDE",
        "Description[en_GB]": "Breeze by the KDE VDG",
        "Description[es]": "Brisa por KDE VDG",
        "Description[eu]": "Brisa KDEren VDGk egina",
        "Description[fr]": "Breeze par l'équipe « KDE VDG »",
        "Description[it]": "Brezza a cura del KDE VDG",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 Breeze",
        "Description[nl]": "Breeze door de KDE VDG",
        "Description[pl]": "Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa da VDG do KDE",
        "Description[ru]": "Оформление рабочей среды Breeze от KDE VDG",
        "Description[sl]": "Sapica od KDE VDG",
        "Description[sv]": "Breeze av KDE:s visuella designgrupp",
        "Description[tr]": "KDE VDG tarafından Esinti",
        "Description[uk]": "Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze, do KDE VDG",
        "Description[x-test]": "xxBreeze by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze",
        "Name[az]": "Breeze",
        "Name[ca@valencia]": "Brisa",
        "Name[ca]": "Brisa",
        "Name[cs]": "Breeze",
        "Name[en_GB]": "Breeze",
        "Name[es]": "Brisa",
        "Name[eu]": "Brisa",
        "Name[fr]": "Breeze",
        "Name[it]": "Brezza",
        "Name[ko]": "Breeze",
        "Name[nl]": "Breeze",
        "Name[pl]": "Bryza",
        "Name[pt]": "Brisa",
        "Name[ru]": "Breeze",
        "Name[sl]": "Sapica",
        "Name[sv]": "Breeze",
        "Name[tr]": "Esinti",
        "Name[uk]": "Breeze",
        "Name[vi]": "Breeze",
        "Name[x-test]": "xxBreezexx",
        "Name[zh_CN]": "Breeze 微风",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> plasma-framework-5.95.0.zip: plasma-framework-5.95.0/src/desktoptheme/breeze/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[it]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队"
            }
        ],
        "Category": "",
        "Description": "Breeze by the KDE VDG",
        "Description[az]": "KDE VDG tərəfindən Breeze İş mühiti görünüşü",
        "Description[ca@valencia]": "Brisa, creat pel VDG de KDE",
        "Description[ca]": "Brisa, creat pel VDG del KDE",
        "Description[en_GB]": "Breeze by the KDE VDG",
        "Description[es]": "Brisa por KDE VDG",
        "Description[eu]": "Brisa KDEren VDGk egina",
        "Description[fi]": "Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze par l'équipe « KDE VDG »",
        "Description[it]": "Brezza a cura del KDE VDG",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 Breeze",
        "Description[nl]": "Breeze door de KDE VDG",
        "Description[pl]": "Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa da VDG do KDE",
        "Description[ru]": "Оформление рабочей среды Breeze от KDE VDG",
        "Description[sl]": "Sapica od KDE VDG",
        "Description[sv]": "Breeze av KDE:s visuella designgrupp",
        "Description[tr]": "KDE VDG tarafından Esinti",
        "Description[uk]": "Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze, do KDE VDG",
        "Description[x-test]": "xxBreeze by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze",
        "Name[az]": "Breeze",
        "Name[ca@valencia]": "Brisa",
        "Name[ca]": "Brisa",
        "Name[cs]": "Breeze",
        "Name[en_GB]": "Breeze",
        "Name[es]": "Brisa",
        "Name[eu]": "Brisa",
        "Name[fi]": "Breeze",
        "Name[fr]": "Breeze",
        "Name[it]": "Brezza",
        "Name[ko]": "Breeze",
        "Name[nl]": "Breeze",
        "Name[pl]": "Bryza",
        "Name[pt]": "Brisa",
        "Name[ru]": "Breeze",
        "Name[sl]": "Sapica",
        "Name[sv]": "Breeze",
        "Name[tr]": "Esinti",
        "Name[uk]": "Breeze",
        "Name[vi]": "Breeze",
        "Name[x-test]": "xxBreezexx",
        "Name[zh_CN]": "Breeze 微风",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
